@@ -20,24 +20,26 @@ class ccache(bb_base):
     def __init__(self, **kwargs):
         """Initialize building block"""
         super(ccache, self).__init__()
-        self.__cache_dir = kwargs.get('cache_dir', '/opt/ccache')
-        self.__cache_size = kwargs.get('cache_size', '5G')
+        self.__cache_dir = kwargs.get("cache_dir", "/opt/ccache")
+        self.__cache_size = kwargs.get("cache_size", "5G")
 
         self.__instructions()
 
     def __instructions(self):
         self += comment(__doc__, reformat=False)
-        self += packages(ospackages=['ccache'])
-        self += shell(commands=[
-            'mkdir -p {0} && chmod 777 {0}'.format(self.__cache_dir)
-        ])
-        self += environment(variables={
-            'CCACHE_DIR': self.__cache_dir,
-            'CCACHE_MAXSIZE': self.__cache_size,
-            'CCACHE_SLOPPINESS': 'pch_defines,time_macros'
-        })
-        self += label(metadata={
-            'ccache.dir': self.__cache_dir,
-            'ccache.size': self.__cache_size
-        })
+        self += packages(ospackages=["ccache"])
+        self += shell(
+            commands=["mkdir -p {0} && chmod 777 {0}".format(self.__cache_dir)]
+        )
+        self += environment(
+            variables={
+                "CCACHE_DIR": self.__cache_dir,
+                "CCACHE_MAXSIZE": self.__cache_size,
+                "CCACHE_SLOPPINESS": "pch_defines,time_macros",
+            }
+        )
+        self += label(
+            metadata={"ccache.dir": self.__cache_dir, "ccache.size": self.__cache_size}
+        )
+
     # No runtime
